@@ -8,11 +8,11 @@ Calendar::Saka - Interface to Saka Calendar (Indian).
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Carp;
 use Readonly;
@@ -723,10 +723,10 @@ sub _validate_date
 
     croak("ERROR: Invalid year [$yyyy].\n")
         unless (defined($yyyy) && ($yyyy =~ /^\d{4}$/) && ($yyyy > 0));
-    croak("ERROR: Invalid month number [$mm].\n")
-        unless (defined($mm) && ($mm =~ /^\d{1,2}$/) && ($mm >= 1 || $mm <= 12));
-    croak("ERROR: Invalid day number [$dd].\n")
-        unless (defined($dd) && ($dd =~ /^\d{1,2}$/) && ($dd >= 1 || $mm <= 31));
+    croak("ERROR: Invalid month [$mm].\n")
+        unless (defined($mm) && ($mm =~ /^\d{1,2}$/) && ($mm >= 1) && ($mm <= 12));
+    croak("ERROR: Invalid day [$dd].\n")
+        unless (defined($dd) && ($dd =~ /^\d{1,2}$/) && ($dd >= 1) && ($dd <= 31));
 }
 
 =head1 AUTHOR
